@@ -9,7 +9,7 @@ from .result_base import (
 from .config_base import ConfigBase, TestConfigBase, MigrationBase
 from .static_base import AttachmentBase, StaticBase
 from .dynamic_base import TaskBase
-from .attachmentBase import AssertBase
+from .attachmentBase import AssertBase, EntityLogBase
 
 __all__ = [
     SessionBase,
@@ -25,4 +25,5 @@ __all__ = [
     RetriedBase,
     AssertBase,
     TestLogBase,
+    EntityLogBase,
 ]
